// ******************************************************
// *                                                    *
// *  main.C (MP3)                                      *
// *                                                    *
// *  Driver file for testing MP3 classes               *
// *                                                    *
// *  Written 13 February 1999 by Jason Zych            *
// *                                                    *
// ******************************************************

#include <iostream.h>
#include "window.h"
#include "button.h"
#include "point.h"

int main()
{
   Window w1;
   w1.SetLocation(0, 0);
   w1.SetSize(50, 50);
   w1.SetNumComponents(5);
   w1.Add(new Button(String("button 1")));
   w1.Add(new Button(String("button 2")));
   w1.Add(new Button(String("button 2")));
   w1.Add(new Button(String("button 2")));
   w1.Add(new Button(String("button 2")));

   w1.Draw(); 

   w1.HandleMouseClick(Point(0, 0));
   w1.SetLocation(43, 43);
   w1.HandleMouseClick(Point(54, 44));


   return 0; 
}

